@@ -136,12 +136,6 @@ func ParseOptions(argv []string) (*Options, error) {
 		return nil, err
 	}
 
-	// If config file flag is not set, and env is, use the env
-	val, ok := os.LookupEnv("SMUG_SESSION_CONFIG_PATH")
-	if *config == "" && ok {
-		*config = val
-	}
-
 	var project string
 	if *config == "" {
 		if errors.Is(cmdErr, ErrCommandNotFound) {
@@ -151,6 +145,12 @@ func ParseOptions(argv []string) (*Options, error) {
 		}
 	}
 
+	// If config file flag is not set, and env is, use the env
+	val, ok := os.LookupEnv("SMUG_SESSION_CONFIG_PATH")
+	if *config == "" && project == "" && ok {
+		*config = val
+	}
+
 	if strings.Contains(project, ":") {
 		parts := strings.Split(project, ":")
 		project = parts[0]
